@@ -4,9 +4,9 @@ Created on 2021-04-06
 @author: wf
 '''
 from ormigrate.toolbox import HelperFunctions as hf
-from smw.rating import Rating,RatingType
-from openresearch.event import EventList
-from smw.pagefixer import PageFixerManager
+from ormigrate.smw.rating import Rating, RatingType, EntityRating
+from datasources.openresearch import OREventManager
+from ormigrate.smw.pagefixer import PageFixerManager
 from ormigrate.fixer import ORFixer
 
 class SeriesFixer(ORFixer):
@@ -23,6 +23,8 @@ class SeriesFixer(ORFixer):
         '''
         super(SeriesFixer, self).__init__(pageFixerManager)
 
+    def rate(self, rating: EntityRating):
+        return self.getRating(rating.getRecord())
 
     def getRating(self,eventRecord):
         '''
@@ -44,9 +46,9 @@ class SeriesFixer(ORFixer):
         '''
         """Test if LOD is returned correctly if called from api to store to SQL"""
         wikiUser=hf.getSMW_WikiUser(save=hf.inPublicCI())
-        eventList=EventList()
+        eventList=OREventManager()
         eventList.debug=self.debug
-        eventRecords=eventList.fromWiki(wikiUser,askExtra=askExtra,profile=self.debug)
+        eventRecords=eventList.smwHandler.fromWiki(wikiUser,askExtra=askExtra,profile=self.debug)
         count = 0
         for eventRecord in eventRecords:
             # print(str(i['series']) + ":", str(type(i['series'])))
